/*
 * Lemonldap::NG styles
 * Default theme for Manager 
 */

@import url(manager.css);

.simpleTree
{
	overflow:auto;
	margin:0;
	padding:0;
}
.simpleTree li
{
    list-style: none;
    margin:0;
    padding:0 0 0 34px;
    line-height: 14px;
}
.simpleTree li span
{
    display:inline;
    clear: left;
    white-space: nowrap;
    cursor:pointer;
}
.simpleTree ul
{
    margin:0; 
    padding:0;
}
.simpleTree .root
{
    margin-left:-16px;
    background: url(../images/tree/root.gif) no-repeat 16px 0 transparent;
    /*background-position: -84px -1646px;width:16px*/
}
.simpleTree .line
{
    margin:0 0 0 -16px;
    padding:0;
    line-height: 3px;
    height:3px;
    font-size:3px;
    background: url(../images/tree/tree.png) 0 0 no-repeat transparent;
    background-position: -84px -1322px;
}
.simpleTree .line-last
{
    margin:0 0 0 -16px;
    padding:0;
    line-height: 3px;
    height:3px;
    font-size:3px;
    background: url(../images/tree/tree.png) 0 0 no-repeat transparent;
    background-position: -84px -1712px;
}
.simpleTree .line-over
{
    margin:0 0 0 -16px;
    padding:0;
    line-height: 3px;
    height:3px;
    font-size:3px;
    background: url(../images/tree/tree.png) 0 0 no-repeat transparent;
    background-position: -84px -1392px;
}
.simpleTree .line-over-last
{
    margin:0 0 0 -16px;
    padding:0;
    line-height: 3px;
    height:3px;
    font-size:3px;
    background: url(../images/tree/tree.png) 0 0 no-repeat transparent;
    background-position: -84px -1462px;
}
.simpleTree .folder-open
{
    margin-left:-16px;
    background: url(../images/tree/tree.png) 0 -2px no-repeat transparent;
    background-position: 0 -72px;width: 34px;
}
.simpleTree .folder-open-last
{
    margin-left:-16px;
    background: url(../images/tree/tree.png) 0 -2px no-repeat transparent;
    background-position: 0 -72px; width: 34px;
}
.simpleTree .folder-close
{
    margin-left:-16px;
    background: url(../images/tree/tree.png) 0 -2px no-repeat transparent;
    background-position: 0 -1394px; width: 34px;height:14px;
}
.simpleTree .folder-close-last
{
    margin-left:-16px;
    background: url(../images/tree/tree.png) 0 -2px no-repeat transparent;
    background-position: 0 -1322px; width: 34px;height:16px;
}
.simpleTree .folder-hidden, .simpleTree .folder-hidden-last
{
	display:none;
}
.simpleTree .doc
{
    margin-left:-16px;
    background: url(../images/tree/tree.png) 0 -1px no-repeat transparent;
    background-position: -84px -72px; width: 32px;height:16px;
}
.simpleTree .doc-last
{
    margin-left:-16px;
    background: url(../images/tree/tree.png) 0 -1px no-repeat transparent;
    background-position: -84px 0; width: 32px;height:16px;
}
.simpleTree .ajax
{
    background: url(../images/spinner.gif) no-repeat 0 0 transparent;
    height: 16px;
    display:none;
}
.simpleTree .ajax li
{
    display:none;
    margin:0; 
    padding:0;
}
.simpleTree .trigger
{
    display:inline;
    margin-left:-32px;
    width: 28px;
    height: 11px;
    cursor:pointer;
}
.simpleTree .text
{
}
.simpleTree .active
{
    background-color:#F7BE77;
    padding:0px 2px;
    border: 1px dashed #444;
}
#drag_container
{
    background:transparent;
    color:#000;
    font: normal 11px arial, tahoma, helvetica, sans-serif;
    border: 1px dashed #767676;
}
#drag_container ul
{
    list-style: none;
    padding:0;
    margin:0;
}

#drag_container li
{
    list-style: none;
    background-color:transparent;
    line-height:18px;
    white-space: nowrap;
    padding:1px 1px 0px 16px;
    margin:0;
}
#drag_container li span
{
    padding:0;
}

#drag_container li.doc, #drag_container li.doc-last
{
    background: url(../images/tree/tree.png) no-repeat -17px 0 transparent;
    background-position: -84px -72px;width:32px;
}
#drag_container .folder-close, #drag_container .folder-close-last
{
    background: url(../images/tree/tree.png) no-repeat -17px 0 transparent;
    background-position: 0 -1394px; width: 34px;
}

#drag_container .folder-open, #drag_container .folder-open-last
{
    background: url(../images/tree/tree.png) no-repeat -17px 0 transparent;
    background-position: 0 -72px; width: 34px;
}

.content
{
    display: block;
}
.hidden
{
    display: none;
}
