/*
 * Lemonldap::NG styles
 * Commin styles for Manager
 *
 * Coding rules:
 *   selector
 *   {
 *   	property:value;
 *   }
 */

/* Main */
html,body
{
	margin:0;
	padding:0;
	height:100%;
	min-height:100%;
	overflow:hidden;
}

body
{
	font:normal 9pt sans-serif;
	background:#000 url('../images/logo_lemonldap-ng.png') no-repeat 10px 10px;
}

.content
{
	display:block;
}

.hidden
{
	display:none;
}

a, a:link, a:visited
{
	text-decoration:none;
}

ul
{
	text-align: left;
	list-style-position:inside;
	list-style-image:url("../images/bullet_orange.png");
}

/* Buttons, Inputs*/
input, select, textarea
{
	font-weight:bold;
	border:1px solid #bbb;
	padding:5px 10px;
	margin:5px;
}

textarea#filearea
{
	font-size:8pt;
	font-family:monospace;
	background-color:#ddd;
}

input#text, select
{
	width:80%;
	text-align:center;
}

input#int
{
	width:100px;
	text-align:center;
}


option
{
	margin:5px;
}

/* Divs */
#header {
	height:40px;
	padding:5px 5px;
	margin:5px 10px;
	text-align: center;
}

#header img 
{
	float:left;
	margin:0 10px
}

#menu
{
	float:left;
	padding:10px;
	margin:0 10px;
	width:300px;
	overflow-x:hidden;
	overflow-y:auto;
}

#buttons, #edition, #help, #data
{
	text-align:center;
	margin:0 10px 10px 340px;
}


#help h1, #buttons h1, #edition h1
{
	text-align:center;
	font-size:12pt;
	padding:5px 10px;
	margin:5px 10px;
	cursor:pointer;
}

#data h1, #data h2
{
	text-align:center;
	font-size:12pt;
	padding:5px 10px;
	margin:5px 10px;
}

#help h1 img, #buttons h1 img, #edition h1 img
{
	vertical-align:bottom;
	margin-bottom:2px;
	margin-right:5px;
}

#help_content, #buttons_content, #content, #data
{
	padding:5px 10px;
	margin:5px 10px;
	overflow:auto;
}

#help_content
{
	padding:5px;
	overflow:hidden;
	text-align:center;
}

#help_content iframe
{
	width:100%;
	height:100%;
}

#query-switch
{
	padding:0;
	margin:10px 0;
}

#css-switch p
{
	margin:10px 0;
	padding:10px;
}

/* Filearea */
#content_filearea table tr td
{
  text-align:left;
  vertical-align:middle;
}
#content_filearea table
{
  margin-left:auto;
  margin-right:auto;
  padding-left:20px;
}
#content_filearea span.loadimg
{
  display:inline-block;
  width:20px;
}

/* saml */
#content_samlAssertion table,
#content_samlService table
{
  margin-left:auto;
  margin-right:auto;
}

/* Sessions explorer */
div.category {
	margin: 5px 50px;
}

div.category h2 {
	margin: 5px 50px;
}

/* Popup */
#popup h3
{
	text-align:center;
	letter-spacing:2px;
	border-bottom:1px solid #aaa;
	padding:5px;
	margin:5px 50px;
}

#popup ul
{
	list-style-position:inside;
	list-style-image:url("../images/bullet_green.png");
	margin:0;
	padding:0;
}

#popup ul.warning {
	list-style-image:url("../images/bullet_orange.png");
}

#popup ul.error {
	list-style-image:url("../images/bullet_red.png");
}

.ui-dialog {
	border:1px solid #000;
	-moz-box-shadow:1px 1px 15px #555;
	-webkit-box-shadow:1px 1px 15px #555;
}

/* Skin selection */
input#skinText {
	text-align: center;
}

#content_skin img, #skinImagePicker img, #content_applicationListApplication img, #appsLogoPicker img {
	margin: 5px;
}

#skinImagePicker, #appsLogoPicker, #css-switch {
	text-align: center;
}

