/*
 * Lemonldap::NG styles
 * Lightness theme for Manager
 */

@import url(manager.css);

/* jQuery Simple Tree */
.simpleTree
{
	margin:0;
	padding:0;
}

.simpleTree ul
{
	text-align:center;
}

.simpleTree li
{
	list-style:none;
	margin:0;
	padding:0 5px;
}

.simpleTree li span
{
	display:block;
	padding:5px 25px;
}

.simpleTree li.doc span, .simpleTree li.doc-last span
{
	color:#444;
	padding:5px;
}

.simpleTree ul
{
	margin:0; 
	padding:0;
}

.simpleTree .root
{
	cursor:pointer;
	text-align:center;
}

.simpleTree .line
{
	line-height:3px;
	height:3px;
	font-size:3px;
}

.simpleTree .ajax
{
	background: url(../images/spinner.gif) no-repeat center 10px;
	height:30px;
	display:none;
}

.simpleTree .ajax li
{
	display:none;
	margin:0; 
	padding:0;
}

.simpleTree .trigger {
	position:relative;
	top:6px;
	left:8px;
}
